==> cdktf-cdktf-provider-googleworkspace-3.0.0.tar.gz: package/lib/data-googleworkspace-groups/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleworkspaceGroupsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/d/groups#id DataGoogleworkspaceGroups#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleworkspaceGroupsGroups {
}
export declare function dataGoogleworkspaceGroupsGroupsToTerraform(struct?: DataGoogleworkspaceGroupsGroups): any;
export declare class DataGoogleworkspaceGroupsGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleworkspaceGroupsGroups | undefined;
    set internalValue(value: DataGoogleworkspaceGroupsGroups | undefined);
    get adminCreated(): cdktf.IResolvable;
    get aliases(): string[];
    get description(): string;
    get directMembersCount(): number;
    get email(): string;
    get etag(): string;
    get id(): string;
    get name(): string;
    get nonEditableAliases(): string[];
}
export declare class DataGoogleworkspaceGroupsGroupsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleworkspaceGroupsGroupsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/googleworkspace/d/groups googleworkspace_groups}
*/
export declare class DataGoogleworkspaceGroups extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "googleworkspace_groups";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/googleworkspace/d/groups googleworkspace_groups} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleworkspaceGroupsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleworkspaceGroupsConfig);
    private _groups;
    get groups(): DataGoogleworkspaceGroupsGroupsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-googleworkspace-5.0.0.tar.gz: package/lib/data-googleworkspace-groups/index.d.ts <==
/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleworkspaceGroupsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/groups#id DataGoogleworkspaceGroups#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleworkspaceGroupsGroups {
}
export declare function dataGoogleworkspaceGroupsGroupsToTerraform(struct?: DataGoogleworkspaceGroupsGroups): any;
export declare class DataGoogleworkspaceGroupsGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleworkspaceGroupsGroups | undefined;
    set internalValue(value: DataGoogleworkspaceGroupsGroups | undefined);
    get adminCreated(): cdktf.IResolvable;
    get aliases(): string[];
    get description(): string;
    get directMembersCount(): number;
    get email(): string;
    get etag(): string;
    get id(): string;
    get name(): string;
    get nonEditableAliases(): string[];
}
export declare class DataGoogleworkspaceGroupsGroupsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleworkspaceGroupsGroupsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/groups googleworkspace_groups}
*/
export declare class DataGoogleworkspaceGroups extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "googleworkspace_groups";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/groups googleworkspace_groups} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleworkspaceGroupsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleworkspaceGroupsConfig);
    private _groups;
    get groups(): DataGoogleworkspaceGroupsGroupsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
